# The PEP 484 type hints stub file for the Qt3DExtras module.
#
# Generated by SIP 5.2.0
#
# Copyright (c) 2019 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt3D.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import typing
import sip

from PyQt5 import QtGui
from PyQt5 import QtCore
from PyQt5 import Qt3DRender
from PyQt5 import Qt3DInput
from PyQt5 import Qt3DCore

# Support for QDate, QDateTime and QTime.
import datetime

# Convenient type aliases.
PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[typing.Callable[..., None], QtCore.pyqtBoundSignal]

# Convenient aliases for complicated OpenGL types.
PYQT_OPENGL_ARRAY = typing.Union[typing.Sequence[int], typing.Sequence[float],
        sip.Buffer, None]
PYQT_OPENGL_BOUND_ARRAY = typing.Union[typing.Sequence[int],
        typing.Sequence[float], sip.Buffer, int, None]


class Qt3DExtras(sip.simplewrapper):

    class QAbstractCameraController(Qt3DCore.QEntity):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def mouseDevice(self) -> Qt3DInput.QMouseDevice: ...
        def keyboardDevice(self) -> Qt3DInput.QKeyboardDevice: ...
        def decelerationChanged(self, deceleration: float) -> None: ...
        def accelerationChanged(self, acceleration: float) -> None: ...
        def lookSpeedChanged(self) -> None: ...
        def linearSpeedChanged(self) -> None: ...
        def cameraChanged(self) -> None: ...
        def setDeceleration(self, deceleration: float) -> None: ...
        def setAcceleration(self, acceleration: float) -> None: ...
        def setLookSpeed(self, lookSpeed: float) -> None: ...
        def setLinearSpeed(self, linearSpeed: float) -> None: ...
        def setCamera(self, camera: Qt3DRender.QCamera) -> None: ...
        def deceleration(self) -> float: ...
        def acceleration(self) -> float: ...
        def lookSpeed(self) -> float: ...
        def linearSpeed(self) -> float: ...
        def camera(self) -> Qt3DRender.QCamera: ...

    class QAbstractSpriteSheet(Qt3DCore.QNode):

        def currentIndexChanged(self, currentIndex: int) -> None: ...
        def textureTransformChanged(self, textureTransform: QtGui.QMatrix3x3) -> None: ...
        def textureChanged(self, texture: Qt3DRender.QAbstractTexture) -> None: ...
        def setCurrentIndex(self, currentIndex: int) -> None: ...
        def setTexture(self, texture: Qt3DRender.QAbstractTexture) -> None: ...
        def currentIndex(self) -> int: ...
        def textureTransform(self) -> QtGui.QMatrix3x3: ...
        def texture(self) -> Qt3DRender.QAbstractTexture: ...

    class QConeGeometry(Qt3DRender.QGeometry):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def lengthChanged(self, length: float) -> None: ...
        def slicesChanged(self, slices: int) -> None: ...
        def ringsChanged(self, rings: int) -> None: ...
        def bottomRadiusChanged(self, bottomRadius: float) -> None: ...
        def topRadiusChanged(self, topRadius: float) -> None: ...
        def hasBottomEndcapChanged(self, hasBottomEndcap: bool) -> None: ...
        def hasTopEndcapChanged(self, hasTopEndcap: bool) -> None: ...
        def setLength(self, length: float) -> None: ...
        def setSlices(self, slices: int) -> None: ...
        def setRings(self, rings: int) -> None: ...
        def setBottomRadius(self, bottomRadius: float) -> None: ...
        def setTopRadius(self, topRadius: float) -> None: ...
        def setHasBottomEndcap(self, hasBottomEndcap: bool) -> None: ...
        def setHasTopEndcap(self, hasTopEndcap: bool) -> None: ...
        def indexAttribute(self) -> Qt3DRender.QAttribute: ...
        def texCoordAttribute(self) -> Qt3DRender.QAttribute: ...
        def normalAttribute(self) -> Qt3DRender.QAttribute: ...
        def positionAttribute(self) -> Qt3DRender.QAttribute: ...
        def length(self) -> float: ...
        def slices(self) -> int: ...
        def rings(self) -> int: ...
        def bottomRadius(self) -> float: ...
        def topRadius(self) -> float: ...
        def hasBottomEndcap(self) -> bool: ...
        def hasTopEndcap(self) -> bool: ...
        def updateIndices(self) -> None: ...
        def updateVertices(self) -> None: ...

    class QConeMesh(Qt3DRender.QGeometryRenderer):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def lengthChanged(self, length: float) -> None: ...
        def slicesChanged(self, slices: int) -> None: ...
        def ringsChanged(self, rings: int) -> None: ...
        def bottomRadiusChanged(self, bottomRadius: float) -> None: ...
        def topRadiusChanged(self, topRadius: float) -> None: ...
        def hasBottomEndcapChanged(self, hasBottomEndcap: bool) -> None: ...
        def hasTopEndcapChanged(self, hasTopEndcap: bool) -> None: ...
        def setLength(self, length: float) -> None: ...
        def setSlices(self, slices: int) -> None: ...
        def setRings(self, rings: int) -> None: ...
        def setBottomRadius(self, bottomRadius: float) -> None: ...
        def setTopRadius(self, topRadius: float) -> None: ...
        def setHasBottomEndcap(self, hasBottomEndcap: bool) -> None: ...
        def setHasTopEndcap(self, hasTopEndcap: bool) -> None: ...
        def length(self) -> float: ...
        def bottomRadius(self) -> float: ...
        def topRadius(self) -> float: ...
        def hasBottomEndcap(self) -> bool: ...
        def hasTopEndcap(self) -> bool: ...
        def slices(self) -> int: ...
        def rings(self) -> int: ...

    class QCuboidGeometry(Qt3DRender.QGeometry):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def xyMeshResolutionChanged(self, xyMeshResolution: QtCore.QSize) -> None: ...
        def xzMeshResolutionChanged(self, xzMeshResolution: QtCore.QSize) -> None: ...
        def yzMeshResolutionChanged(self, yzMeshResolution: QtCore.QSize) -> None: ...
        def zExtentChanged(self, zExtent: float) -> None: ...
        def yExtentChanged(self, yExtent: float) -> None: ...
        def xExtentChanged(self, xExtent: float) -> None: ...
        def setXYMeshResolution(self, resolution: QtCore.QSize) -> None: ...
        def setXZMeshResolution(self, resolution: QtCore.QSize) -> None: ...
        def setYZMeshResolution(self, resolution: QtCore.QSize) -> None: ...
        def setZExtent(self, zExtent: float) -> None: ...
        def setYExtent(self, yExtent: float) -> None: ...
        def setXExtent(self, xExtent: float) -> None: ...
        def indexAttribute(self) -> Qt3DRender.QAttribute: ...
        def tangentAttribute(self) -> Qt3DRender.QAttribute: ...
        def texCoordAttribute(self) -> Qt3DRender.QAttribute: ...
        def normalAttribute(self) -> Qt3DRender.QAttribute: ...
        def positionAttribute(self) -> Qt3DRender.QAttribute: ...
        def xzMeshResolution(self) -> QtCore.QSize: ...
        def xyMeshResolution(self) -> QtCore.QSize: ...
        def yzMeshResolution(self) -> QtCore.QSize: ...
        def zExtent(self) -> float: ...
        def yExtent(self) -> float: ...
        def xExtent(self) -> float: ...
        def updateVertices(self) -> None: ...
        def updateIndices(self) -> None: ...

    class QCuboidMesh(Qt3DRender.QGeometryRenderer):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def xyMeshResolutionChanged(self, xyMeshResolution: QtCore.QSize) -> None: ...
        def xzMeshResolutionChanged(self, xzMeshResolution: QtCore.QSize) -> None: ...
        def yzMeshResolutionChanged(self, yzMeshResolution: QtCore.QSize) -> None: ...
        def zExtentChanged(self, zExtent: float) -> None: ...
        def yExtentChanged(self, yExtent: float) -> None: ...
        def xExtentChanged(self, xExtent: float) -> None: ...
        def setXYMeshResolution(self, resolution: QtCore.QSize) -> None: ...
        def setXZMeshResolution(self, resolution: QtCore.QSize) -> None: ...
        def setYZMeshResolution(self, resolution: QtCore.QSize) -> None: ...
        def setZExtent(self, zExtent: float) -> None: ...
        def setYExtent(self, yExtent: float) -> None: ...
        def setXExtent(self, xExtent: float) -> None: ...
        def xyMeshResolution(self) -> QtCore.QSize: ...
        def xzMeshResolution(self) -> QtCore.QSize: ...
        def yzMeshResolution(self) -> QtCore.QSize: ...
        def zExtent(self) -> float: ...
        def yExtent(self) -> float: ...
        def xExtent(self) -> float: ...

    class QCylinderGeometry(Qt3DRender.QGeometry):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def lengthChanged(self, length: float) -> None: ...
        def slicesChanged(self, slices: int) -> None: ...
        def ringsChanged(self, rings: int) -> None: ...
        def radiusChanged(self, radius: float) -> None: ...
        def setLength(self, length: float) -> None: ...
        def setRadius(self, radius: float) -> None: ...
        def setSlices(self, slices: int) -> None: ...
        def setRings(self, rings: int) -> None: ...
        def indexAttribute(self) -> Qt3DRender.QAttribute: ...
        def texCoordAttribute(self) -> Qt3DRender.QAttribute: ...
        def normalAttribute(self) -> Qt3DRender.QAttribute: ...
        def positionAttribute(self) -> Qt3DRender.QAttribute: ...
        def length(self) -> float: ...
        def radius(self) -> float: ...
        def slices(self) -> int: ...
        def rings(self) -> int: ...
        def updateIndices(self) -> None: ...
        def updateVertices(self) -> None: ...

    class QCylinderMesh(Qt3DRender.QGeometryRenderer):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def lengthChanged(self, length: float) -> None: ...
        def slicesChanged(self, slices: int) -> None: ...
        def ringsChanged(self, rings: int) -> None: ...
        def radiusChanged(self, radius: float) -> None: ...
        def setLength(self, length: float) -> None: ...
        def setRadius(self, radius: float) -> None: ...
        def setSlices(self, slices: int) -> None: ...
        def setRings(self, rings: int) -> None: ...
        def length(self) -> float: ...
        def radius(self) -> float: ...
        def slices(self) -> int: ...
        def rings(self) -> int: ...

    class QDiffuseMapMaterial(Qt3DRender.QMaterial):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def textureScaleChanged(self, textureScale: float) -> None: ...
        def shininessChanged(self, shininess: float) -> None: ...
        def specularChanged(self, specular: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def diffuseChanged(self, diffuse: Qt3DRender.QAbstractTexture) -> None: ...
        def ambientChanged(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setTextureScale(self, textureScale: float) -> None: ...
        def setDiffuse(self, diffuse: Qt3DRender.QAbstractTexture) -> None: ...
        def setShininess(self, shininess: float) -> None: ...
        def setSpecular(self, specular: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setAmbient(self, color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def textureScale(self) -> float: ...
        def diffuse(self) -> Qt3DRender.QAbstractTexture: ...
        def shininess(self) -> float: ...
        def specular(self) -> QtGui.QColor: ...
        def ambient(self) -> QtGui.QColor: ...

    class QDiffuseSpecularMapMaterial(Qt3DRender.QMaterial):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def textureScaleChanged(self, textureScale: float) -> None: ...
        def shininessChanged(self, shininess: float) -> None: ...
        def specularChanged(self, specular: Qt3DRender.QAbstractTexture) -> None: ...
        def diffuseChanged(self, diffuse: Qt3DRender.QAbstractTexture) -> None: ...
        def ambientChanged(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setTextureScale(self, textureScale: float) -> None: ...
        def setShininess(self, shininess: float) -> None: ...
        def setSpecular(self, specular: Qt3DRender.QAbstractTexture) -> None: ...
        def setDiffuse(self, diffuse: Qt3DRender.QAbstractTexture) -> None: ...
        def setAmbient(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def textureScale(self) -> float: ...
        def shininess(self) -> float: ...
        def specular(self) -> Qt3DRender.QAbstractTexture: ...
        def diffuse(self) -> Qt3DRender.QAbstractTexture: ...
        def ambient(self) -> QtGui.QColor: ...

    class QDiffuseSpecularMaterial(Qt3DRender.QMaterial):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def alphaBlendingEnabledChanged(self, enabled: bool) -> None: ...
        def textureScaleChanged(self, textureScale: float) -> None: ...
        def normalChanged(self, normal: typing.Any) -> None: ...
        def shininessChanged(self, shininess: float) -> None: ...
        def specularChanged(self, specular: typing.Any) -> None: ...
        def diffuseChanged(self, diffuse: typing.Any) -> None: ...
        def ambientChanged(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setAlphaBlendingEnabled(self, enabled: bool) -> None: ...
        def setTextureScale(self, textureScale: float) -> None: ...
        def setNormal(self, normal: typing.Any) -> None: ...
        def setShininess(self, shininess: float) -> None: ...
        def setSpecular(self, specular: typing.Any) -> None: ...
        def setDiffuse(self, diffuse: typing.Any) -> None: ...
        def setAmbient(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def isAlphaBlendingEnabled(self) -> bool: ...
        def textureScale(self) -> float: ...
        def normal(self) -> typing.Any: ...
        def shininess(self) -> float: ...
        def specular(self) -> typing.Any: ...
        def diffuse(self) -> typing.Any: ...
        def ambient(self) -> QtGui.QColor: ...

    class QExtrudedTextGeometry(Qt3DRender.QGeometry):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def depthChanged(self, extrusionLength: float) -> None: ...
        def fontChanged(self, font: QtGui.QFont) -> None: ...
        def textChanged(self, text: str) -> None: ...
        def setDepth(self, extrusionLength: float) -> None: ...
        def setFont(self, font: QtGui.QFont) -> None: ...
        def setText(self, text: str) -> None: ...
        def extrusionLength(self) -> float: ...
        def font(self) -> QtGui.QFont: ...
        def text(self) -> str: ...
        def indexAttribute(self) -> Qt3DRender.QAttribute: ...
        def normalAttribute(self) -> Qt3DRender.QAttribute: ...
        def positionAttribute(self) -> Qt3DRender.QAttribute: ...

    class QExtrudedTextMesh(Qt3DRender.QGeometryRenderer):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def depthChanged(self, depth: float) -> None: ...
        def fontChanged(self, font: QtGui.QFont) -> None: ...
        def textChanged(self, text: str) -> None: ...
        def setDepth(self, depth: float) -> None: ...
        def setFont(self, font: QtGui.QFont) -> None: ...
        def setText(self, text: str) -> None: ...
        def depth(self) -> float: ...
        def font(self) -> QtGui.QFont: ...
        def text(self) -> str: ...

    class QFirstPersonCameraController('QAbstractCameraController'):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

    class QForwardRenderer(Qt3DRender.QTechniqueFilter):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def buffersToClearChanged(self, a0: Qt3DRender.QClearBuffers.BufferType) -> None: ...
        def setBuffersToClear(self, a0: Qt3DRender.QClearBuffers.BufferType) -> None: ...
        def buffersToClear(self) -> Qt3DRender.QClearBuffers.BufferType: ...
        def gammaChanged(self, gamma: float) -> None: ...
        def frustumCullingEnabledChanged(self, enabled: bool) -> None: ...
        def setGamma(self, gamma: float) -> None: ...
        def setFrustumCullingEnabled(self, enabled: bool) -> None: ...
        def gamma(self) -> float: ...
        def isFrustumCullingEnabled(self) -> bool: ...
        def externalRenderTargetSizeChanged(self, size: QtCore.QSize) -> None: ...
        def surfaceChanged(self, surface: QtCore.QObject) -> None: ...
        def cameraChanged(self, camera: Qt3DCore.QEntity) -> None: ...
        def clearColorChanged(self, clearColor: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def viewportRectChanged(self, viewportRect: QtCore.QRectF) -> None: ...
        def setExternalRenderTargetSize(self, size: QtCore.QSize) -> None: ...
        def setSurface(self, surface: QtCore.QObject) -> None: ...
        def setCamera(self, camera: Qt3DCore.QEntity) -> None: ...
        def setClearColor(self, clearColor: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setViewportRect(self, viewportRect: QtCore.QRectF) -> None: ...
        def externalRenderTargetSize(self) -> QtCore.QSize: ...
        def surface(self) -> QtCore.QObject: ...
        def camera(self) -> Qt3DCore.QEntity: ...
        def clearColor(self) -> QtGui.QColor: ...
        def viewportRect(self) -> QtCore.QRectF: ...

    class QGoochMaterial(Qt3DRender.QMaterial):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def shininessChanged(self, shininess: float) -> None: ...
        def betaChanged(self, beta: float) -> None: ...
        def alphaChanged(self, alpha: float) -> None: ...
        def warmChanged(self, warm: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def coolChanged(self, cool: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def specularChanged(self, specular: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def diffuseChanged(self, diffuse: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setShininess(self, shininess: float) -> None: ...
        def setBeta(self, beta: float) -> None: ...
        def setAlpha(self, alpha: float) -> None: ...
        def setWarm(self, warm: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setCool(self, cool: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setSpecular(self, specular: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setDiffuse(self, diffuse: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def shininess(self) -> float: ...
        def beta(self) -> float: ...
        def alpha(self) -> float: ...
        def warm(self) -> QtGui.QColor: ...
        def cool(self) -> QtGui.QColor: ...
        def specular(self) -> QtGui.QColor: ...
        def diffuse(self) -> QtGui.QColor: ...

    class QMetalRoughMaterial(Qt3DRender.QMaterial):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def textureScaleChanged(self, textureScale: float) -> None: ...
        def normalChanged(self, normal: typing.Any) -> None: ...
        def ambientOcclusionChanged(self, ambientOcclusion: typing.Any) -> None: ...
        def roughnessChanged(self, roughness: typing.Any) -> None: ...
        def metalnessChanged(self, metalness: typing.Any) -> None: ...
        def baseColorChanged(self, baseColor: typing.Any) -> None: ...
        def setTextureScale(self, textureScale: float) -> None: ...
        def setNormal(self, normal: typing.Any) -> None: ...
        def setAmbientOcclusion(self, ambientOcclusion: typing.Any) -> None: ...
        def setRoughness(self, roughness: typing.Any) -> None: ...
        def setMetalness(self, metalness: typing.Any) -> None: ...
        def setBaseColor(self, baseColor: typing.Any) -> None: ...
        def textureScale(self) -> float: ...
        def normal(self) -> typing.Any: ...
        def ambientOcclusion(self) -> typing.Any: ...
        def roughness(self) -> typing.Any: ...
        def metalness(self) -> typing.Any: ...
        def baseColor(self) -> typing.Any: ...

    class QMorphPhongMaterial(Qt3DRender.QMaterial):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def interpolatorChanged(self, interpolator: float) -> None: ...
        def shininessChanged(self, shininess: float) -> None: ...
        def specularChanged(self, specular: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def diffuseChanged(self, diffuse: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def ambientChanged(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setInterpolator(self, interpolator: float) -> None: ...
        def setShininess(self, shininess: float) -> None: ...
        def setSpecular(self, specular: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setDiffuse(self, diffuse: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setAmbient(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def interpolator(self) -> float: ...
        def shininess(self) -> float: ...
        def specular(self) -> QtGui.QColor: ...
        def diffuse(self) -> QtGui.QColor: ...
        def ambient(self) -> QtGui.QColor: ...

    class QNormalDiffuseMapMaterial(Qt3DRender.QMaterial):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def textureScaleChanged(self, textureScale: float) -> None: ...
        def shininessChanged(self, shininess: float) -> None: ...
        def specularChanged(self, specular: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def normalChanged(self, normal: Qt3DRender.QAbstractTexture) -> None: ...
        def diffuseChanged(self, diffuse: Qt3DRender.QAbstractTexture) -> None: ...
        def ambientChanged(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setTextureScale(self, textureScale: float) -> None: ...
        def setShininess(self, shininess: float) -> None: ...
        def setNormal(self, normal: Qt3DRender.QAbstractTexture) -> None: ...
        def setDiffuse(self, diffuse: Qt3DRender.QAbstractTexture) -> None: ...
        def setSpecular(self, specular: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setAmbient(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def textureScale(self) -> float: ...
        def shininess(self) -> float: ...
        def normal(self) -> Qt3DRender.QAbstractTexture: ...
        def diffuse(self) -> Qt3DRender.QAbstractTexture: ...
        def specular(self) -> QtGui.QColor: ...
        def ambient(self) -> QtGui.QColor: ...

    class QNormalDiffuseMapAlphaMaterial('QNormalDiffuseMapMaterial'):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

    class QNormalDiffuseSpecularMapMaterial(Qt3DRender.QMaterial):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def textureScaleChanged(self, textureScale: float) -> None: ...
        def shininessChanged(self, shininess: float) -> None: ...
        def specularChanged(self, specular: Qt3DRender.QAbstractTexture) -> None: ...
        def normalChanged(self, normal: Qt3DRender.QAbstractTexture) -> None: ...
        def diffuseChanged(self, diffuse: Qt3DRender.QAbstractTexture) -> None: ...
        def ambientChanged(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setTextureScale(self, textureScale: float) -> None: ...
        def setShininess(self, shininess: float) -> None: ...
        def setSpecular(self, specular: Qt3DRender.QAbstractTexture) -> None: ...
        def setNormal(self, normal: Qt3DRender.QAbstractTexture) -> None: ...
        def setDiffuse(self, diffuse: Qt3DRender.QAbstractTexture) -> None: ...
        def setAmbient(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def textureScale(self) -> float: ...
        def shininess(self) -> float: ...
        def specular(self) -> Qt3DRender.QAbstractTexture: ...
        def normal(self) -> Qt3DRender.QAbstractTexture: ...
        def diffuse(self) -> Qt3DRender.QAbstractTexture: ...
        def ambient(self) -> QtGui.QColor: ...

    class QOrbitCameraController('QAbstractCameraController'):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def zoomInLimitChanged(self) -> None: ...
        def setZoomInLimit(self, zoomInLimit: float) -> None: ...
        def zoomInLimit(self) -> float: ...

    class QPerVertexColorMaterial(Qt3DRender.QMaterial):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

    class QPhongAlphaMaterial(Qt3DRender.QMaterial):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def blendFunctionArgChanged(self, blendFunctionArg: Qt3DRender.QBlendEquation.BlendFunction) -> None: ...
        def destinationAlphaArgChanged(self, destinationAlphaArg: Qt3DRender.QBlendEquationArguments.Blending) -> None: ...
        def sourceAlphaArgChanged(self, sourceAlphaArg: Qt3DRender.QBlendEquationArguments.Blending) -> None: ...
        def destinationRgbArgChanged(self, destinationRgbArg: Qt3DRender.QBlendEquationArguments.Blending) -> None: ...
        def sourceRgbArgChanged(self, sourceRgbArg: Qt3DRender.QBlendEquationArguments.Blending) -> None: ...
        def setBlendFunctionArg(self, blendFunctionArg: Qt3DRender.QBlendEquation.BlendFunction) -> None: ...
        def setDestinationAlphaArg(self, destinationAlphaArg: Qt3DRender.QBlendEquationArguments.Blending) -> None: ...
        def setSourceAlphaArg(self, sourceAlphaArg: Qt3DRender.QBlendEquationArguments.Blending) -> None: ...
        def setDestinationRgbArg(self, destinationRgbArg: Qt3DRender.QBlendEquationArguments.Blending) -> None: ...
        def setSourceRgbArg(self, sourceRgbArg: Qt3DRender.QBlendEquationArguments.Blending) -> None: ...
        def blendFunctionArg(self) -> Qt3DRender.QBlendEquation.BlendFunction: ...
        def destinationAlphaArg(self) -> Qt3DRender.QBlendEquationArguments.Blending: ...
        def sourceAlphaArg(self) -> Qt3DRender.QBlendEquationArguments.Blending: ...
        def destinationRgbArg(self) -> Qt3DRender.QBlendEquationArguments.Blending: ...
        def sourceRgbArg(self) -> Qt3DRender.QBlendEquationArguments.Blending: ...
        def alphaChanged(self, alpha: float) -> None: ...
        def shininessChanged(self, shininess: float) -> None: ...
        def specularChanged(self, specular: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def diffuseChanged(self, diffuse: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def ambientChanged(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setAlpha(self, alpha: float) -> None: ...
        def setShininess(self, shininess: float) -> None: ...
        def setSpecular(self, specular: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setDiffuse(self, diffuse: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setAmbient(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def alpha(self) -> float: ...
        def shininess(self) -> float: ...
        def specular(self) -> QtGui.QColor: ...
        def diffuse(self) -> QtGui.QColor: ...
        def ambient(self) -> QtGui.QColor: ...

    class QPhongMaterial(Qt3DRender.QMaterial):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def shininessChanged(self, shininess: float) -> None: ...
        def specularChanged(self, specular: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def diffuseChanged(self, diffuse: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def ambientChanged(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setShininess(self, shininess: float) -> None: ...
        def setSpecular(self, specular: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setDiffuse(self, diffuse: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setAmbient(self, ambient: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def shininess(self) -> float: ...
        def specular(self) -> QtGui.QColor: ...
        def diffuse(self) -> QtGui.QColor: ...
        def ambient(self) -> QtGui.QColor: ...

    class QPlaneGeometry(Qt3DRender.QGeometry):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def mirroredChanged(self, mirrored: bool) -> None: ...
        def setMirrored(self, mirrored: bool) -> None: ...
        def mirrored(self) -> bool: ...
        def heightChanged(self, height: float) -> None: ...
        def widthChanged(self, width: float) -> None: ...
        def resolutionChanged(self, resolution: QtCore.QSize) -> None: ...
        def setHeight(self, height: float) -> None: ...
        def setWidth(self, width: float) -> None: ...
        def setResolution(self, resolution: QtCore.QSize) -> None: ...
        def indexAttribute(self) -> Qt3DRender.QAttribute: ...
        def tangentAttribute(self) -> Qt3DRender.QAttribute: ...
        def texCoordAttribute(self) -> Qt3DRender.QAttribute: ...
        def normalAttribute(self) -> Qt3DRender.QAttribute: ...
        def positionAttribute(self) -> Qt3DRender.QAttribute: ...
        def height(self) -> float: ...
        def width(self) -> float: ...
        def resolution(self) -> QtCore.QSize: ...
        def updateIndices(self) -> None: ...
        def updateVertices(self) -> None: ...

    class QPlaneMesh(Qt3DRender.QGeometryRenderer):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def mirroredChanged(self, mirrored: bool) -> None: ...
        def setMirrored(self, mirrored: bool) -> None: ...
        def mirrored(self) -> bool: ...
        def heightChanged(self, height: float) -> None: ...
        def widthChanged(self, width: float) -> None: ...
        def meshResolutionChanged(self, meshResolution: QtCore.QSize) -> None: ...
        def setMeshResolution(self, resolution: QtCore.QSize) -> None: ...
        def setHeight(self, height: float) -> None: ...
        def setWidth(self, width: float) -> None: ...
        def meshResolution(self) -> QtCore.QSize: ...
        def height(self) -> float: ...
        def width(self) -> float: ...

    class QSkyboxEntity(Qt3DCore.QEntity):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def gammaCorrectEnabledChanged(self, enabled: bool) -> None: ...
        def baseNameChanged(self, path: str) -> None: ...
        def setGammaCorrectEnabled(self, enabled: bool) -> None: ...
        def isGammaCorrectEnabled(self) -> bool: ...
        def extensionChanged(self, extension: str) -> None: ...
        def extension(self) -> str: ...
        def setExtension(self, extension: str) -> None: ...
        def baseName(self) -> str: ...
        def setBaseName(self, path: str) -> None: ...

    class QSphereGeometry(Qt3DRender.QGeometry):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def generateTangentsChanged(self, generateTangents: bool) -> None: ...
        def slicesChanged(self, slices: int) -> None: ...
        def ringsChanged(self, rings: int) -> None: ...
        def radiusChanged(self, radius: float) -> None: ...
        def setGenerateTangents(self, gen: bool) -> None: ...
        def setRadius(self, radius: float) -> None: ...
        def setSlices(self, slices: int) -> None: ...
        def setRings(self, rings: int) -> None: ...
        def indexAttribute(self) -> Qt3DRender.QAttribute: ...
        def tangentAttribute(self) -> Qt3DRender.QAttribute: ...
        def texCoordAttribute(self) -> Qt3DRender.QAttribute: ...
        def normalAttribute(self) -> Qt3DRender.QAttribute: ...
        def positionAttribute(self) -> Qt3DRender.QAttribute: ...
        def radius(self) -> float: ...
        def slices(self) -> int: ...
        def rings(self) -> int: ...
        def generateTangents(self) -> bool: ...
        def updateIndices(self) -> None: ...
        def updateVertices(self) -> None: ...

    class QSphereMesh(Qt3DRender.QGeometryRenderer):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def generateTangentsChanged(self, generateTangents: bool) -> None: ...
        def slicesChanged(self, slices: int) -> None: ...
        def ringsChanged(self, rings: int) -> None: ...
        def radiusChanged(self, radius: float) -> None: ...
        def setGenerateTangents(self, gen: bool) -> None: ...
        def setRadius(self, radius: float) -> None: ...
        def setSlices(self, slices: int) -> None: ...
        def setRings(self, rings: int) -> None: ...
        def generateTangents(self) -> bool: ...
        def radius(self) -> float: ...
        def slices(self) -> int: ...
        def rings(self) -> int: ...

    class QSpriteGrid('QAbstractSpriteSheet'):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def columnsChanged(self, columns: int) -> None: ...
        def rowsChanged(self, rows: int) -> None: ...
        def setColumns(self, columns: int) -> None: ...
        def setRows(self, rows: int) -> None: ...
        def columns(self) -> int: ...
        def rows(self) -> int: ...

    class QSpriteSheet('QAbstractSpriteSheet'):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def spritesChanged(self, sprites: typing.Iterable['QSpriteSheetItem']) -> None: ...
        def setSprites(self, sprites: typing.Iterable['QSpriteSheetItem']) -> None: ...
        def removeSprite(self, sprite: 'QSpriteSheetItem') -> None: ...
        @typing.overload
        def addSprite(self, x: int, y: int, width: int, height: int) -> 'QSpriteSheetItem': ...
        @typing.overload
        def addSprite(self, sprite: 'QSpriteSheetItem') -> None: ...
        def sprites(self) -> typing.List['QSpriteSheetItem']: ...

    class QSpriteSheetItem(Qt3DCore.QNode):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def heightChanged(self, height: int) -> None: ...
        def widthChanged(self, width: int) -> None: ...
        def yChanged(self, y: int) -> None: ...
        def xChanged(self, x: int) -> None: ...
        def setHeight(self, height: int) -> None: ...
        def setWidth(self, width: int) -> None: ...
        def setY(self, y: int) -> None: ...
        def setX(self, x: int) -> None: ...
        def height(self) -> int: ...
        def width(self) -> int: ...
        def y(self) -> int: ...
        def x(self) -> int: ...

    class Qt3DWindow(QtGui.QWindow):

        def __init__(self, screen: typing.Optional[QtGui.QScreen] = ...) -> None: ...

        def event(self, e: QtCore.QEvent) -> bool: ...
        def resizeEvent(self, a0: QtGui.QResizeEvent) -> None: ...
        def showEvent(self, e: QtGui.QShowEvent) -> None: ...
        def renderSettings(self) -> Qt3DRender.QRenderSettings: ...
        def camera(self) -> Qt3DRender.QCamera: ...
        def defaultFrameGraph(self) -> 'QForwardRenderer': ...
        def activeFrameGraph(self) -> Qt3DRender.QFrameGraphNode: ...
        def setActiveFrameGraph(self, activeFrameGraph: Qt3DRender.QFrameGraphNode) -> None: ...
        def setRootEntity(self, root: Qt3DCore.QEntity) -> None: ...
        @typing.overload
        def registerAspect(self, aspect: Qt3DCore.QAbstractAspect) -> None: ...
        @typing.overload
        def registerAspect(self, name: str) -> None: ...

    class QText2DEntity(Qt3DCore.QEntity):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def heightChanged(self, height: float) -> None: ...
        def widthChanged(self, width: float) -> None: ...
        def textChanged(self, text: str) -> None: ...
        def colorChanged(self, color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def fontChanged(self, font: QtGui.QFont) -> None: ...
        def setHeight(self, height: float) -> None: ...
        def setWidth(self, width: float) -> None: ...
        def height(self) -> float: ...
        def width(self) -> float: ...
        def setText(self, text: str) -> None: ...
        def text(self) -> str: ...
        def setColor(self, color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def color(self) -> QtGui.QColor: ...
        def setFont(self, font: QtGui.QFont) -> None: ...
        def font(self) -> QtGui.QFont: ...

    class QTexturedMetalRoughMaterial('QMetalRoughMaterial'):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def normalChanged(self, normal: typing.Any) -> None: ...
        def ambientOcclusionChanged(self, ambientOcclusion: typing.Any) -> None: ...

    class QTextureMaterial(Qt3DRender.QMaterial):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def alphaBlendingEnabledChanged(self, enabled: bool) -> None: ...
        def textureTransformChanged(self, textureTransform: QtGui.QMatrix3x3) -> None: ...
        def textureOffsetChanged(self, textureOffset: QtGui.QVector2D) -> None: ...
        def textureChanged(self, texture: Qt3DRender.QAbstractTexture) -> None: ...
        def setAlphaBlendingEnabled(self, enabled: bool) -> None: ...
        def setTextureTransform(self, matrix: QtGui.QMatrix3x3) -> None: ...
        def setTextureOffset(self, textureOffset: QtGui.QVector2D) -> None: ...
        def setTexture(self, texture: Qt3DRender.QAbstractTexture) -> None: ...
        def isAlphaBlendingEnabled(self) -> bool: ...
        def textureTransform(self) -> QtGui.QMatrix3x3: ...
        def textureOffset(self) -> QtGui.QVector2D: ...
        def texture(self) -> Qt3DRender.QAbstractTexture: ...

    class QTorusGeometry(Qt3DRender.QGeometry):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def minorRadiusChanged(self, minorRadius: float) -> None: ...
        def slicesChanged(self, slices: int) -> None: ...
        def ringsChanged(self, rings: int) -> None: ...
        def radiusChanged(self, radius: float) -> None: ...
        def setMinorRadius(self, minorRadius: float) -> None: ...
        def setRadius(self, radius: float) -> None: ...
        def setSlices(self, slices: int) -> None: ...
        def setRings(self, rings: int) -> None: ...
        def indexAttribute(self) -> Qt3DRender.QAttribute: ...
        def texCoordAttribute(self) -> Qt3DRender.QAttribute: ...
        def normalAttribute(self) -> Qt3DRender.QAttribute: ...
        def positionAttribute(self) -> Qt3DRender.QAttribute: ...
        def minorRadius(self) -> float: ...
        def radius(self) -> float: ...
        def slices(self) -> int: ...
        def rings(self) -> int: ...
        def updateIndices(self) -> None: ...
        def updateVertices(self) -> None: ...

    class QTorusMesh(Qt3DRender.QGeometryRenderer):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def minorRadiusChanged(self, minorRadius: float) -> None: ...
        def slicesChanged(self, slices: int) -> None: ...
        def ringsChanged(self, rings: int) -> None: ...
        def radiusChanged(self, radius: float) -> None: ...
        def setMinorRadius(self, minorRadius: float) -> None: ...
        def setRadius(self, radius: float) -> None: ...
        def setSlices(self, slices: int) -> None: ...
        def setRings(self, rings: int) -> None: ...
        def minorRadius(self) -> float: ...
        def radius(self) -> float: ...
        def slices(self) -> int: ...
        def rings(self) -> int: ...



# The PEP 484 type hints stub file for the Qt3DCore module.
#
# Generated by SIP 5.2.0
#
# Copyright (c) 2019 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt3D.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import typing
import sip

from PyQt5 import QtGui
from PyQt5 import QtCore

# Support for QDate, QDateTime and QTime.
import datetime

# Convenient type aliases.
PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[typing.Callable[..., None], QtCore.pyqtBoundSignal]

# Convenient aliases for complicated OpenGL types.
PYQT_OPENGL_ARRAY = typing.Union[typing.Sequence[int], typing.Sequence[float],
        sip.Buffer, None]
PYQT_OPENGL_BOUND_ARRAY = typing.Union[typing.Sequence[int],
        typing.Sequence[float], sip.Buffer, int, None]


class Qt3DCore(sip.simplewrapper):

    class ChangeFlag(int): ...
    NodeCreated = ... # type: 'ChangeFlag'
    NodeDeleted = ... # type: 'ChangeFlag'
    PropertyUpdated = ... # type: 'ChangeFlag'
    PropertyValueAdded = ... # type: 'ChangeFlag'
    PropertyValueRemoved = ... # type: 'ChangeFlag'
    ComponentAdded = ... # type: 'ChangeFlag'
    ComponentRemoved = ... # type: 'ChangeFlag'
    CommandRequested = ... # type: 'ChangeFlag'
    CallbackTriggered = ... # type: 'ChangeFlag'
    AllChanges = ... # type: 'ChangeFlag'

    class QAbstractAspect(QtCore.QObject):

        def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None: ...

        def unregisterBackendType(self, a0: QtCore.QMetaObject) -> None: ...
        def registerBackendType(self, a0: QtCore.QMetaObject, functor: 'QBackendNodeMapper') -> None: ...
        def rootEntityId(self) -> 'QNodeId': ...

    class QAspectEngine(QtCore.QObject):

        class RunMode(int): ...
        Manual = ... # type: 'QAspectEngine.RunMode'
        Automatic = ... # type: 'QAspectEngine.RunMode'

        def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None: ...

        def processFrame(self) -> None: ...
        def runMode(self) -> 'QAspectEngine.RunMode': ...
        def setRunMode(self, mode: 'QAspectEngine.RunMode') -> None: ...
        def executeCommand(self, command: str) -> typing.Any: ...
        def aspects(self) -> typing.List['QAbstractAspect']: ...
        @typing.overload
        def unregisterAspect(self, aspect: 'QAbstractAspect') -> None: ...
        @typing.overload
        def unregisterAspect(self, name: str) -> None: ...
        @typing.overload
        def registerAspect(self, aspect: 'QAbstractAspect') -> None: ...
        @typing.overload
        def registerAspect(self, name: str) -> None: ...
        def rootEntity(self) -> 'QEntity': ...
        def setRootEntity(self, root: 'QEntity') -> None: ...

    class QNode(QtCore.QObject):

        class PropertyTrackingMode(int): ...
        TrackFinalValues = ... # type: 'QNode.PropertyTrackingMode'
        DontTrackValues = ... # type: 'QNode.PropertyTrackingMode'
        TrackAllValues = ... # type: 'QNode.PropertyTrackingMode'

        def __init__(self, parent: typing.Optional['QNode'] = ...) -> None: ...

        def sendReply(self, command: 'QNodeCommand') -> None: ...
        def sendCommand(self, name: str, data: typing.Any = ..., replyTo: int = ...) -> int: ...
        def defaultPropertyTrackingModeChanged(self, mode: 'QNode.PropertyTrackingMode') -> None: ...
        def setDefaultPropertyTrackingMode(self, mode: 'QNode.PropertyTrackingMode') -> None: ...
        def clearPropertyTrackings(self) -> None: ...
        def clearPropertyTracking(self, propertyName: str) -> None: ...
        def propertyTracking(self, propertyName: str) -> 'QNode.PropertyTrackingMode': ...
        def setPropertyTracking(self, propertyName: str, trackMode: 'QNode.PropertyTrackingMode') -> None: ...
        def defaultPropertyTrackingMode(self) -> 'QNode.PropertyTrackingMode': ...
        def sceneChangeEvent(self, change: 'QSceneChange') -> None: ...
        def notifyObservers(self, change: 'QSceneChange') -> None: ...
        def nodeDestroyed(self) -> None: ...
        def enabledChanged(self, enabled: bool) -> None: ...
        def parentChanged(self, parent: QtCore.QObject) -> None: ...
        def setEnabled(self, isEnabled: bool) -> None: ...
        def setParent(self, parent: 'QNode') -> None: ...
        def isEnabled(self) -> bool: ...
        def childNodes(self) -> typing.List['QNode']: ...
        def blockNotifications(self, block: bool) -> bool: ...
        def notificationsBlocked(self) -> bool: ...
        def parentNode(self) -> 'QNode': ...
        def id(self) -> 'QNodeId': ...

    class QAbstractSkeleton('QNode'):

        def sceneChangeEvent(self, change: 'QSceneChange') -> None: ...
        def jointCountChanged(self, jointCount: int) -> None: ...
        def jointCount(self) -> int: ...

    class QComponent('QNode'):

        def __init__(self, parent: typing.Optional['QNode'] = ...) -> None: ...

        def removedFromEntity(self, entity: 'QEntity') -> None: ...
        def addedToEntity(self, entity: 'QEntity') -> None: ...
        def shareableChanged(self, isShareable: bool) -> None: ...
        def setShareable(self, isShareable: bool) -> None: ...
        def entities(self) -> typing.List['QEntity']: ...
        def isShareable(self) -> bool: ...

    class QArmature('QComponent'):

        def __init__(self, parent: typing.Optional['QNode'] = ...) -> None: ...

        def skeletonChanged(self, skeleton: 'QAbstractSkeleton') -> None: ...
        def setSkeleton(self, skeleton: 'QAbstractSkeleton') -> None: ...
        def skeleton(self) -> 'QAbstractSkeleton': ...

    class QBackendNodeMapper(sip.simplewrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QBackendNodeMapper') -> None: ...

        def destroy(self, id: 'QNodeId') -> None: ...
        def get(self, id: 'QNodeId') -> 'QBackendNode': ...
        def create(self, change: 'QNodeCreatedChangeBase') -> 'QBackendNode': ...

    class QBackendNode(sip.simplewrapper):

        class Mode(int): ...
        ReadOnly = ... # type: 'QBackendNode.Mode'
        ReadWrite = ... # type: 'QBackendNode.Mode'

        def __init__(self, mode: 'QBackendNode.Mode' = ...) -> None: ...

        def sendReply(self, command: 'QNodeCommand') -> None: ...
        def sendCommand(self, name: str, data: typing.Any, replyTo: int = ...) -> int: ...
        def sceneChangeEvent(self, e: 'QSceneChange') -> None: ...
        def notifyObservers(self, e: 'QSceneChange') -> None: ...
        def mode(self) -> 'QBackendNode.Mode': ...
        def isEnabled(self) -> bool: ...
        def setEnabled(self, enabled: bool) -> None: ...
        def peerId(self) -> 'QNodeId': ...

    class QSceneChange(sip.simplewrapper):

        class DeliveryFlag(int): ...
        BackendNodes = ... # type: 'QSceneChange.DeliveryFlag'
        Nodes = ... # type: 'QSceneChange.DeliveryFlag'
        DeliverToAll = ... # type: 'QSceneChange.DeliveryFlag'

        class DeliveryFlags(sip.simplewrapper):

            @typing.overload
            def __init__(self) -> None: ...
            @typing.overload
            def __init__(self, f: typing.Union['QSceneChange.DeliveryFlags', 'QSceneChange.DeliveryFlag']) -> None: ...
            @typing.overload
            def __init__(self, a0: 'QSceneChange.DeliveryFlags') -> None: ...

            def __hash__(self) -> int: ...
            def __bool__(self) -> int: ...
            def __invert__(self) -> 'QSceneChange.DeliveryFlags': ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...

        def __init__(self, type: 'ChangeFlag', subjectId: 'QNodeId') -> None: ...

        def subjectId(self) -> 'QNodeId': ...
        def deliveryFlags(self) -> 'QSceneChange.DeliveryFlags': ...
        def setDeliveryFlags(self, flags: typing.Union['QSceneChange.DeliveryFlags', 'QSceneChange.DeliveryFlag']) -> None: ...
        def type(self) -> 'ChangeFlag': ...

    class QComponentAddedChange('QSceneChange'):

        @typing.overload
        def __init__(self, entity: 'QEntity', component: 'QComponent') -> None: ...
        @typing.overload
        def __init__(self, component: 'QComponent', entity: 'QEntity') -> None: ...

        def componentMetaObject(self) -> QtCore.QMetaObject: ...
        def componentId(self) -> 'QNodeId': ...
        def entityId(self) -> 'QNodeId': ...

    class QComponentRemovedChange('QSceneChange'):

        @typing.overload
        def __init__(self, entity: 'QEntity', component: 'QComponent') -> None: ...
        @typing.overload
        def __init__(self, component: 'QComponent', entity: 'QEntity') -> None: ...

        def componentMetaObject(self) -> QtCore.QMetaObject: ...
        def componentId(self) -> 'QNodeId': ...
        def entityId(self) -> 'QNodeId': ...

    class QPropertyUpdatedChangeBase('QSceneChange'):

        def __init__(self, subjectId: 'QNodeId') -> None: ...

    class QDynamicPropertyUpdatedChange('QPropertyUpdatedChangeBase'):

        def __init__(self, subjectId: 'QNodeId') -> None: ...

        def setValue(self, value: typing.Any) -> None: ...
        def value(self) -> typing.Any: ...
        def setPropertyName(self, name: typing.Union[QtCore.QByteArray, bytes, bytearray]) -> None: ...
        def propertyName(self) -> QtCore.QByteArray: ...

    class QEntity('QNode'):

        def __init__(self, parent: typing.Optional['QNode'] = ...) -> None: ...

        def parentEntity(self) -> 'QEntity': ...
        def removeComponent(self, comp: 'QComponent') -> None: ...
        def addComponent(self, comp: 'QComponent') -> None: ...
        def components(self) -> typing.List['QComponent']: ...

    class QJoint('QNode'):

        def __init__(self, parent: typing.Optional['QNode'] = ...) -> None: ...

        def nameChanged(self, name: str) -> None: ...
        def rotationZChanged(self, rotationZ: float) -> None: ...
        def rotationYChanged(self, rotationY: float) -> None: ...
        def rotationXChanged(self, rotationX: float) -> None: ...
        def inverseBindMatrixChanged(self, inverseBindMatrix: QtGui.QMatrix4x4) -> None: ...
        def translationChanged(self, translation: QtGui.QVector3D) -> None: ...
        def rotationChanged(self, rotation: QtGui.QQuaternion) -> None: ...
        def scaleChanged(self, scale: QtGui.QVector3D) -> None: ...
        def setToIdentity(self) -> None: ...
        def setName(self, name: str) -> None: ...
        def setRotationZ(self, rotationZ: float) -> None: ...
        def setRotationY(self, rotationY: float) -> None: ...
        def setRotationX(self, rotationX: float) -> None: ...
        def setInverseBindMatrix(self, inverseBindMatrix: QtGui.QMatrix4x4) -> None: ...
        def setTranslation(self, translation: QtGui.QVector3D) -> None: ...
        def setRotation(self, rotation: QtGui.QQuaternion) -> None: ...
        def setScale(self, scale: QtGui.QVector3D) -> None: ...
        def childJoints(self) -> typing.List['QJoint']: ...
        def removeChildJoint(self, joint: 'QJoint') -> None: ...
        def addChildJoint(self, joint: 'QJoint') -> None: ...
        def name(self) -> str: ...
        def rotationZ(self) -> float: ...
        def rotationY(self) -> float: ...
        def rotationX(self) -> float: ...
        def inverseBindMatrix(self) -> QtGui.QMatrix4x4: ...
        def translation(self) -> QtGui.QVector3D: ...
        def rotation(self) -> QtGui.QQuaternion: ...
        def scale(self) -> QtGui.QVector3D: ...

    class QNodeIdTypePair(sip.simplewrapper):

        id = ... # type: 'QNodeId'
        type = ... # type: QtCore.QMetaObject

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, _id: 'QNodeId', _type: QtCore.QMetaObject) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QNodeIdTypePair') -> None: ...

    class QNodeCommand('QSceneChange'):

        def __init__(self, id: 'QNodeId') -> None: ...

        def setReplyToCommandId(self, id: int) -> None: ...
        def inReplyTo(self) -> int: ...
        def setData(self, data: typing.Any) -> None: ...
        def data(self) -> typing.Any: ...
        def setName(self, name: str) -> None: ...
        def name(self) -> str: ...
        def commandId(self) -> int: ...

    class QNodeCreatedChangeBase('QSceneChange'):

        def __init__(self, node: 'QNode') -> None: ...

        def isNodeEnabled(self) -> bool: ...
        def metaObject(self) -> QtCore.QMetaObject: ...
        def parentId(self) -> 'QNodeId': ...

    class QNodeDestroyedChange('QSceneChange'):

        def __init__(self, node: 'QNode', subtreeIdsAndTypes: typing.Iterable['QNodeIdTypePair']) -> None: ...

        def subtreeIdsAndTypes(self) -> typing.List['QNodeIdTypePair']: ...

    class QNodeId(sip.simplewrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QNodeId') -> None: ...

        def __hash__(self) -> int: ...
        def __int__(self) -> bool: ...
        def id(self) -> int: ...
        def isNull(self) -> bool: ...
        @staticmethod
        def createId() -> 'QNodeId': ...

    class QPropertyValueAddedChangeBase('QSceneChange'):

        def __init__(self, subjectId: 'QNodeId') -> None: ...

    class QStaticPropertyValueAddedChangeBase('QPropertyValueAddedChangeBase'):

        def __init__(self, subjectId: 'QNodeId') -> None: ...

        def setPropertyName(self, name: str) -> None: ...
        def propertyName(self) -> str: ...

    class QPropertyNodeAddedChange('QStaticPropertyValueAddedChangeBase'):

        def __init__(self, subjectId: 'QNodeId', node: 'QNode') -> None: ...

        def metaObject(self) -> QtCore.QMetaObject: ...
        def addedNodeId(self) -> 'QNodeId': ...

    class QPropertyValueRemovedChangeBase('QSceneChange'):

        def __init__(self, subjectId: 'QNodeId') -> None: ...

    class QStaticPropertyValueRemovedChangeBase('QPropertyValueRemovedChangeBase'):

        def __init__(self, subjectId: 'QNodeId') -> None: ...

        def setPropertyName(self, name: str) -> None: ...
        def propertyName(self) -> str: ...

    class QPropertyNodeRemovedChange('QStaticPropertyValueRemovedChangeBase'):

        def __init__(self, subjectId: 'QNodeId', node: 'QNode') -> None: ...

        def metaObject(self) -> QtCore.QMetaObject: ...
        def removedNodeId(self) -> 'QNodeId': ...

    class QStaticPropertyUpdatedChangeBase('QPropertyUpdatedChangeBase'):

        def __init__(self, subjectId: 'QNodeId') -> None: ...

        def setPropertyName(self, name: str) -> None: ...
        def propertyName(self) -> str: ...

    class QPropertyUpdatedChange('QStaticPropertyUpdatedChangeBase'):

        def __init__(self, subjectId: 'QNodeId') -> None: ...

        def setValue(self, value: typing.Any) -> None: ...
        def value(self) -> typing.Any: ...

    class QPropertyValueAddedChange('QStaticPropertyValueAddedChangeBase'):

        def __init__(self, subjectId: 'QNodeId') -> None: ...

        def addedValue(self) -> typing.Any: ...
        def setAddedValue(self, value: typing.Any) -> None: ...

    class QPropertyValueRemovedChange('QStaticPropertyValueRemovedChangeBase'):

        def __init__(self, subjectId: 'QNodeId') -> None: ...

        def removedValue(self) -> typing.Any: ...
        def setRemovedValue(self, value: typing.Any) -> None: ...

    class ChangeFlags(sip.simplewrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, f: typing.Union['ChangeFlags', 'ChangeFlag']) -> None: ...
        @typing.overload
        def __init__(self, a0: 'ChangeFlags') -> None: ...

        def __hash__(self) -> int: ...
        def __bool__(self) -> int: ...
        def __invert__(self) -> 'ChangeFlags': ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...

    class QSkeleton('QAbstractSkeleton'):

        def __init__(self, parent: typing.Optional['QNode'] = ...) -> None: ...

        def rootJointChanged(self, rootJoint: 'QJoint') -> None: ...
        def setRootJoint(self, rootJoint: 'QJoint') -> None: ...
        def rootJoint(self) -> 'QJoint': ...

    class QSkeletonLoader('QAbstractSkeleton'):

        class Status(int): ...
        NotReady = ... # type: 'QSkeletonLoader.Status'
        Ready = ... # type: 'QSkeletonLoader.Status'
        Error = ... # type: 'QSkeletonLoader.Status'

        @typing.overload
        def __init__(self, parent: typing.Optional['QNode'] = ...) -> None: ...
        @typing.overload
        def __init__(self, source: QtCore.QUrl, parent: typing.Optional['QNode'] = ...) -> None: ...

        def sceneChangeEvent(self, change: 'QSceneChange') -> None: ...
        def rootJointChanged(self, rootJoint: 'QJoint') -> None: ...
        def createJointsEnabledChanged(self, createJointsEnabled: bool) -> None: ...
        def statusChanged(self, status: 'QSkeletonLoader.Status') -> None: ...
        def sourceChanged(self, source: QtCore.QUrl) -> None: ...
        def setCreateJointsEnabled(self, enabled: bool) -> None: ...
        def setSource(self, source: QtCore.QUrl) -> None: ...
        def rootJoint(self) -> 'QJoint': ...
        def isCreateJointsEnabled(self) -> bool: ...
        def status(self) -> 'QSkeletonLoader.Status': ...
        def source(self) -> QtCore.QUrl: ...

    class QTransform('QComponent'):

        def __init__(self, parent: typing.Optional['QNode'] = ...) -> None: ...

        def sceneChangeEvent(self, change: 'QSceneChange') -> None: ...
        def worldMatrixChanged(self, worldMatrix: QtGui.QMatrix4x4) -> None: ...
        def worldMatrix(self) -> QtGui.QMatrix4x4: ...
        def rotationZChanged(self, rotationZ: float) -> None: ...
        def rotationYChanged(self, rotationY: float) -> None: ...
        def rotationXChanged(self, rotationX: float) -> None: ...
        def matrixChanged(self) -> None: ...
        def translationChanged(self, translation: QtGui.QVector3D) -> None: ...
        def rotationChanged(self, rotation: QtGui.QQuaternion) -> None: ...
        def scale3DChanged(self, scale: QtGui.QVector3D) -> None: ...
        def scaleChanged(self, scale: float) -> None: ...
        def setRotationZ(self, rotationZ: float) -> None: ...
        def setRotationY(self, rotationY: float) -> None: ...
        def setRotationX(self, rotationX: float) -> None: ...
        def setMatrix(self, matrix: QtGui.QMatrix4x4) -> None: ...
        def setTranslation(self, translation: QtGui.QVector3D) -> None: ...
        def setRotation(self, rotation: QtGui.QQuaternion) -> None: ...
        def setScale3D(self, scale: QtGui.QVector3D) -> None: ...
        def setScale(self, scale: float) -> None: ...
        def rotationZ(self) -> float: ...
        def rotationY(self) -> float: ...
        def rotationX(self) -> float: ...
        def matrix(self) -> QtGui.QMatrix4x4: ...
        @staticmethod
        def rotateFromAxes(xAxis: QtGui.QVector3D, yAxis: QtGui.QVector3D, zAxis: QtGui.QVector3D) -> QtGui.QMatrix4x4: ...
        @staticmethod
        def rotateAround(point: QtGui.QVector3D, angle: float, axis: QtGui.QVector3D) -> QtGui.QMatrix4x4: ...
        @typing.overload
        @staticmethod
        def fromEulerAngles(eulerAngles: QtGui.QVector3D) -> QtGui.QQuaternion: ...
        @typing.overload
        @staticmethod
        def fromEulerAngles(pitch: float, yaw: float, roll: float) -> QtGui.QQuaternion: ...
        @typing.overload
        @staticmethod
        def fromAxesAndAngles(axis1: QtGui.QVector3D, angle1: float, axis2: QtGui.QVector3D, angle2: float) -> QtGui.QQuaternion: ...
        @typing.overload
        @staticmethod
        def fromAxesAndAngles(axis1: QtGui.QVector3D, angle1: float, axis2: QtGui.QVector3D, angle2: float, axis3: QtGui.QVector3D, angle3: float) -> QtGui.QQuaternion: ...
        @typing.overload
        @staticmethod
        def fromAxisAndAngle(axis: QtGui.QVector3D, angle: float) -> QtGui.QQuaternion: ...
        @typing.overload
        @staticmethod
        def fromAxisAndAngle(x: float, y: float, z: float, angle: float) -> QtGui.QQuaternion: ...
        @staticmethod
        def fromAxes(xAxis: QtGui.QVector3D, yAxis: QtGui.QVector3D, zAxis: QtGui.QVector3D) -> QtGui.QQuaternion: ...
        def translation(self) -> QtGui.QVector3D: ...
        def rotation(self) -> QtGui.QQuaternion: ...
        def scale3D(self) -> QtGui.QVector3D: ...
        def scale(self) -> float: ...

    def qIdForNode(self, node: 'QNode') -> 'QNodeId': ...



# The PEP 484 type hints stub file for the Qt3DInput module.
#
# Generated by SIP 5.2.0
#
# Copyright (c) 2019 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt3D.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import typing
import sip

from PyQt5 import QtGui
from PyQt5 import QtCore
from PyQt5 import Qt3DCore

# Support for QDate, QDateTime and QTime.
import datetime

# Convenient type aliases.
PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[typing.Callable[..., None], QtCore.pyqtBoundSignal]

# Convenient aliases for complicated OpenGL types.
PYQT_OPENGL_ARRAY = typing.Union[typing.Sequence[int], typing.Sequence[float],
        sip.Buffer, None]
PYQT_OPENGL_BOUND_ARRAY = typing.Union[typing.Sequence[int],
        typing.Sequence[float], sip.Buffer, int, None]


class Qt3DInput(sip.simplewrapper):

    class QAbstractActionInput(Qt3DCore.QNode): ...

    class QAbstractAxisInput(Qt3DCore.QNode):

        def sourceDeviceChanged(self, sourceDevice: 'QAbstractPhysicalDevice') -> None: ...
        def setSourceDevice(self, sourceDevice: 'QAbstractPhysicalDevice') -> None: ...
        def sourceDevice(self) -> 'QAbstractPhysicalDevice': ...

    class QAbstractPhysicalDevice(Qt3DCore.QNode):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def axisSettings(self) -> typing.List['QAxisSetting']: ...
        def removeAxisSetting(self, axisSetting: 'QAxisSetting') -> None: ...
        def addAxisSetting(self, axisSetting: 'QAxisSetting') -> None: ...
        def buttonIdentifier(self, name: str) -> int: ...
        def axisIdentifier(self, name: str) -> int: ...
        def buttonNames(self) -> typing.List[str]: ...
        def axisNames(self) -> typing.List[str]: ...
        def buttonCount(self) -> int: ...
        def axisCount(self) -> int: ...

    class QAction(Qt3DCore.QNode):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def sceneChangeEvent(self, change: Qt3DCore.QSceneChange) -> None: ...
        def activeChanged(self, isActive: bool) -> None: ...
        def inputs(self) -> typing.List['QAbstractActionInput']: ...
        def removeInput(self, input: 'QAbstractActionInput') -> None: ...
        def addInput(self, input: 'QAbstractActionInput') -> None: ...
        def isActive(self) -> bool: ...

    class QActionInput('QAbstractActionInput'):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def buttonsChanged(self, buttons: typing.Iterable[int]) -> None: ...
        def sourceDeviceChanged(self, sourceDevice: 'QAbstractPhysicalDevice') -> None: ...
        def setButtons(self, buttons: typing.Iterable[int]) -> None: ...
        def setSourceDevice(self, sourceDevice: 'QAbstractPhysicalDevice') -> None: ...
        def buttons(self) -> typing.List[int]: ...
        def sourceDevice(self) -> 'QAbstractPhysicalDevice': ...

    class QAnalogAxisInput('QAbstractAxisInput'):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def axisChanged(self, axis: int) -> None: ...
        def setAxis(self, axis: int) -> None: ...
        def axis(self) -> int: ...

    class QAxis(Qt3DCore.QNode):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def sceneChangeEvent(self, change: Qt3DCore.QSceneChange) -> None: ...
        def valueChanged(self, value: float) -> None: ...
        def value(self) -> float: ...
        def inputs(self) -> typing.List['QAbstractAxisInput']: ...
        def removeInput(self, input: 'QAbstractAxisInput') -> None: ...
        def addInput(self, input: 'QAbstractAxisInput') -> None: ...

    class QAxisAccumulator(Qt3DCore.QComponent):

        class SourceAxisType(int): ...
        Velocity = ... # type: 'QAxisAccumulator.SourceAxisType'
        Acceleration = ... # type: 'QAxisAccumulator.SourceAxisType'

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def sceneChangeEvent(self, change: Qt3DCore.QSceneChange) -> None: ...
        def scaleChanged(self, scale: float) -> None: ...
        def velocityChanged(self, value: float) -> None: ...
        def valueChanged(self, value: float) -> None: ...
        def sourceAxisTypeChanged(self, sourceAxisType: 'QAxisAccumulator.SourceAxisType') -> None: ...
        def sourceAxisChanged(self, sourceAxis: 'QAxis') -> None: ...
        def setScale(self, scale: float) -> None: ...
        def setSourceAxisType(self, sourceAxisType: 'QAxisAccumulator.SourceAxisType') -> None: ...
        def setSourceAxis(self, sourceAxis: 'QAxis') -> None: ...
        def scale(self) -> float: ...
        def velocity(self) -> float: ...
        def value(self) -> float: ...
        def sourceAxisType(self) -> 'QAxisAccumulator.SourceAxisType': ...
        def sourceAxis(self) -> 'QAxis': ...

    class QAxisSetting(Qt3DCore.QNode):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def smoothChanged(self, smooth: bool) -> None: ...
        def axesChanged(self, axes: typing.Iterable[int]) -> None: ...
        def deadZoneRadiusChanged(self, deadZoneRadius: float) -> None: ...
        def setSmoothEnabled(self, enabled: bool) -> None: ...
        def setAxes(self, axes: typing.Iterable[int]) -> None: ...
        def setDeadZoneRadius(self, deadZoneRadius: float) -> None: ...
        def isSmoothEnabled(self) -> bool: ...
        def axes(self) -> typing.List[int]: ...
        def deadZoneRadius(self) -> float: ...

    class QButtonAxisInput('QAbstractAxisInput'):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def decelerationChanged(self, deceleration: float) -> None: ...
        def accelerationChanged(self, acceleration: float) -> None: ...
        def buttonsChanged(self, buttons: typing.Iterable[int]) -> None: ...
        def scaleChanged(self, scale: float) -> None: ...
        def setDeceleration(self, deceleration: float) -> None: ...
        def setAcceleration(self, acceleration: float) -> None: ...
        def setButtons(self, buttons: typing.Iterable[int]) -> None: ...
        def setScale(self, scale: float) -> None: ...
        def deceleration(self) -> float: ...
        def acceleration(self) -> float: ...
        def buttons(self) -> typing.List[int]: ...
        def scale(self) -> float: ...

    class QInputAspect(Qt3DCore.QAbstractAspect):

        def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None: ...

        def availablePhysicalDevices(self) -> typing.List[str]: ...
        def createPhysicalDevice(self, name: str) -> 'QAbstractPhysicalDevice': ...

    class QInputChord('QAbstractActionInput'):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def timeoutChanged(self, timeout: int) -> None: ...
        def setTimeout(self, timeout: int) -> None: ...
        def chords(self) -> typing.List['QAbstractActionInput']: ...
        def removeChord(self, input: 'QAbstractActionInput') -> None: ...
        def addChord(self, input: 'QAbstractActionInput') -> None: ...
        def timeout(self) -> int: ...

    class QInputSequence('QAbstractActionInput'):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def buttonIntervalChanged(self, buttonInterval: int) -> None: ...
        def timeoutChanged(self, timeout: int) -> None: ...
        def setButtonInterval(self, buttonInterval: int) -> None: ...
        def setTimeout(self, timeout: int) -> None: ...
        def sequences(self) -> typing.List['QAbstractActionInput']: ...
        def removeSequence(self, input: 'QAbstractActionInput') -> None: ...
        def addSequence(self, input: 'QAbstractActionInput') -> None: ...
        def buttonInterval(self) -> int: ...
        def timeout(self) -> int: ...

    class QInputSettings(Qt3DCore.QComponent):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def eventSourceChanged(self, a0: QtCore.QObject) -> None: ...
        def setEventSource(self, eventSource: QtCore.QObject) -> None: ...
        def eventSource(self) -> QtCore.QObject: ...

    class QKeyboardDevice('QAbstractPhysicalDevice'):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def activeInputChanged(self, activeInput: 'QKeyboardHandler') -> None: ...
        def sceneChangeEvent(self, change: Qt3DCore.QSceneChange) -> None: ...
        def buttonIdentifier(self, name: str) -> int: ...
        def axisIdentifier(self, name: str) -> int: ...
        def buttonNames(self) -> typing.List[str]: ...
        def axisNames(self) -> typing.List[str]: ...
        def buttonCount(self) -> int: ...
        def axisCount(self) -> int: ...
        def activeInput(self) -> 'QKeyboardHandler': ...

    class QKeyboardHandler(Qt3DCore.QComponent):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def sceneChangeEvent(self, change: Qt3DCore.QSceneChange) -> None: ...
        def released(self, event: 'QKeyEvent') -> None: ...
        def pressed(self, event: 'QKeyEvent') -> None: ...
        def volumeDownPressed(self, event: 'QKeyEvent') -> None: ...
        def volumeUpPressed(self, event: 'QKeyEvent') -> None: ...
        def menuPressed(self, event: 'QKeyEvent') -> None: ...
        def flipPressed(self, event: 'QKeyEvent') -> None: ...
        def hangupPressed(self, event: 'QKeyEvent') -> None: ...
        def callPressed(self, event: 'QKeyEvent') -> None: ...
        def context4Pressed(self, event: 'QKeyEvent') -> None: ...
        def context3Pressed(self, event: 'QKeyEvent') -> None: ...
        def context2Pressed(self, event: 'QKeyEvent') -> None: ...
        def context1Pressed(self, event: 'QKeyEvent') -> None: ...
        def noPressed(self, event: 'QKeyEvent') -> None: ...
        def yesPressed(self, event: 'QKeyEvent') -> None: ...
        def selectPressed(self, event: 'QKeyEvent') -> None: ...
        def cancelPressed(self, event: 'QKeyEvent') -> None: ...
        def backPressed(self, event: 'QKeyEvent') -> None: ...
        def spacePressed(self, event: 'QKeyEvent') -> None: ...
        def deletePressed(self, event: 'QKeyEvent') -> None: ...
        def enterPressed(self, event: 'QKeyEvent') -> None: ...
        def returnPressed(self, event: 'QKeyEvent') -> None: ...
        def escapePressed(self, event: 'QKeyEvent') -> None: ...
        def numberSignPressed(self, event: 'QKeyEvent') -> None: ...
        def asteriskPressed(self, event: 'QKeyEvent') -> None: ...
        def backtabPressed(self, event: 'QKeyEvent') -> None: ...
        def tabPressed(self, event: 'QKeyEvent') -> None: ...
        def downPressed(self, event: 'QKeyEvent') -> None: ...
        def upPressed(self, event: 'QKeyEvent') -> None: ...
        def rightPressed(self, event: 'QKeyEvent') -> None: ...
        def leftPressed(self, event: 'QKeyEvent') -> None: ...
        def digit9Pressed(self, event: 'QKeyEvent') -> None: ...
        def digit8Pressed(self, event: 'QKeyEvent') -> None: ...
        def digit7Pressed(self, event: 'QKeyEvent') -> None: ...
        def digit6Pressed(self, event: 'QKeyEvent') -> None: ...
        def digit5Pressed(self, event: 'QKeyEvent') -> None: ...
        def digit4Pressed(self, event: 'QKeyEvent') -> None: ...
        def digit3Pressed(self, event: 'QKeyEvent') -> None: ...
        def digit2Pressed(self, event: 'QKeyEvent') -> None: ...
        def digit1Pressed(self, event: 'QKeyEvent') -> None: ...
        def digit0Pressed(self, event: 'QKeyEvent') -> None: ...
        def focusChanged(self, focus: bool) -> None: ...
        def sourceDeviceChanged(self, keyboardDevice: 'QKeyboardDevice') -> None: ...
        def setFocus(self, focus: bool) -> None: ...
        def setSourceDevice(self, keyboardDevice: 'QKeyboardDevice') -> None: ...
        def focus(self) -> bool: ...
        def sourceDevice(self) -> 'QKeyboardDevice': ...

    class QKeyEvent(QtCore.QObject):

        @typing.overload
        def __init__(self, type: QtCore.QEvent.Type, key: int, modifiers: typing.Union[QtCore.Qt.KeyboardModifiers, QtCore.Qt.KeyboardModifier], text: str = ..., autorep: bool = ..., count: int = ...) -> None: ...
        @typing.overload
        def __init__(self, ke: QtGui.QKeyEvent) -> None: ...

        def matches(self, key_: QtGui.QKeySequence.StandardKey) -> bool: ...
        def type(self) -> QtCore.QEvent.Type: ...
        def setAccepted(self, accepted: bool) -> None: ...
        def isAccepted(self) -> bool: ...
        def nativeScanCode(self) -> int: ...
        def count(self) -> int: ...
        def isAutoRepeat(self) -> bool: ...
        def modifiers(self) -> int: ...
        def text(self) -> str: ...
        def key(self) -> int: ...

    class QLogicalDevice(Qt3DCore.QComponent):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def axes(self) -> typing.List['QAxis']: ...
        def removeAxis(self, axis: 'QAxis') -> None: ...
        def addAxis(self, axis: 'QAxis') -> None: ...
        def actions(self) -> typing.List['QAction']: ...
        def removeAction(self, action: 'QAction') -> None: ...
        def addAction(self, action: 'QAction') -> None: ...

    class QMouseDevice('QAbstractPhysicalDevice'):

        class Axis(int): ...
        X = ... # type: 'QMouseDevice.Axis'
        Y = ... # type: 'QMouseDevice.Axis'
        WheelX = ... # type: 'QMouseDevice.Axis'
        WheelY = ... # type: 'QMouseDevice.Axis'

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def sceneChangeEvent(self, change: Qt3DCore.QSceneChange) -> None: ...
        def sensitivityChanged(self, value: float) -> None: ...
        def setSensitivity(self, value: float) -> None: ...
        def sensitivity(self) -> float: ...
        def buttonIdentifier(self, name: str) -> int: ...
        def axisIdentifier(self, name: str) -> int: ...
        def buttonNames(self) -> typing.List[str]: ...
        def axisNames(self) -> typing.List[str]: ...
        def buttonCount(self) -> int: ...
        def axisCount(self) -> int: ...

    class QMouseEvent(QtCore.QObject):

        class Modifiers(int): ...
        NoModifier = ... # type: 'QMouseEvent.Modifiers'
        ShiftModifier = ... # type: 'QMouseEvent.Modifiers'
        ControlModifier = ... # type: 'QMouseEvent.Modifiers'
        AltModifier = ... # type: 'QMouseEvent.Modifiers'
        MetaModifier = ... # type: 'QMouseEvent.Modifiers'
        KeypadModifier = ... # type: 'QMouseEvent.Modifiers'

        class Buttons(int): ...
        LeftButton = ... # type: 'QMouseEvent.Buttons'
        RightButton = ... # type: 'QMouseEvent.Buttons'
        MiddleButton = ... # type: 'QMouseEvent.Buttons'
        BackButton = ... # type: 'QMouseEvent.Buttons'
        NoButton = ... # type: 'QMouseEvent.Buttons'

        def __init__(self, e: QtGui.QMouseEvent) -> None: ...

        def type(self) -> QtCore.QEvent.Type: ...
        def setAccepted(self, accepted: bool) -> None: ...
        def isAccepted(self) -> bool: ...
        def modifiers(self) -> 'QMouseEvent.Modifiers': ...
        def buttons(self) -> int: ...
        def button(self) -> 'QMouseEvent.Buttons': ...
        def wasHeld(self) -> bool: ...
        def y(self) -> int: ...
        def x(self) -> int: ...

    class QWheelEvent(QtCore.QObject):

        class Modifiers(int): ...
        NoModifier = ... # type: 'QWheelEvent.Modifiers'
        ShiftModifier = ... # type: 'QWheelEvent.Modifiers'
        ControlModifier = ... # type: 'QWheelEvent.Modifiers'
        AltModifier = ... # type: 'QWheelEvent.Modifiers'
        MetaModifier = ... # type: 'QWheelEvent.Modifiers'
        KeypadModifier = ... # type: 'QWheelEvent.Modifiers'

        class Buttons(int): ...
        LeftButton = ... # type: 'QWheelEvent.Buttons'
        RightButton = ... # type: 'QWheelEvent.Buttons'
        MiddleButton = ... # type: 'QWheelEvent.Buttons'
        BackButton = ... # type: 'QWheelEvent.Buttons'
        NoButton = ... # type: 'QWheelEvent.Buttons'

        def __init__(self, e: QtGui.QWheelEvent) -> None: ...

        def type(self) -> QtCore.QEvent.Type: ...
        def setAccepted(self, accepted: bool) -> None: ...
        def isAccepted(self) -> bool: ...
        def modifiers(self) -> 'QWheelEvent.Modifiers': ...
        def buttons(self) -> int: ...
        def angleDelta(self) -> QtCore.QPoint: ...
        def y(self) -> int: ...
        def x(self) -> int: ...

    class QMouseHandler(Qt3DCore.QComponent):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def sceneChangeEvent(self, change: Qt3DCore.QSceneChange) -> None: ...
        def wheel(self, wheel: 'QWheelEvent') -> None: ...
        def positionChanged(self, mouse: 'QMouseEvent') -> None: ...
        def pressAndHold(self, mouse: 'QMouseEvent') -> None: ...
        def released(self, mouse: 'QMouseEvent') -> None: ...
        def pressed(self, mouse: 'QMouseEvent') -> None: ...
        def exited(self) -> None: ...
        def entered(self) -> None: ...
        def doubleClicked(self, mouse: 'QMouseEvent') -> None: ...
        def clicked(self, mouse: 'QMouseEvent') -> None: ...
        def containsMouseChanged(self, containsMouse: bool) -> None: ...
        def sourceDeviceChanged(self, mouseDevice: 'QMouseDevice') -> None: ...
        def setSourceDevice(self, mouseDevice: 'QMouseDevice') -> None: ...
        def containsMouse(self) -> bool: ...
        def sourceDevice(self) -> 'QMouseDevice': ...

    class QPhysicalDeviceCreatedChangeBase(Qt3DCore.QNodeCreatedChangeBase):

        def __init__(self, device: 'QAbstractPhysicalDevice') -> None: ...

        def axisSettingIds(self) -> typing.List[Qt3DCore.QNodeId]: ...



# The PEP 484 type hints stub file for the Qt3DLogic module.
#
# Generated by SIP 5.2.0
#
# Copyright (c) 2019 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt3D.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import typing
import sip

from PyQt5 import Qt3DCore

# Support for QDate, QDateTime and QTime.
import datetime

# Convenient type aliases.
PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[typing.Callable[..., None], QtCore.pyqtBoundSignal]

# Convenient aliases for complicated OpenGL types.
PYQT_OPENGL_ARRAY = typing.Union[typing.Sequence[int], typing.Sequence[float],
        sip.Buffer, None]
PYQT_OPENGL_BOUND_ARRAY = typing.Union[typing.Sequence[int],
        typing.Sequence[float], sip.Buffer, int, None]


class Qt3DLogic(sip.simplewrapper):

    class QFrameAction(Qt3DCore.QComponent):

        def __init__(self, parent: typing.Optional[Qt3DCore.QNode] = ...) -> None: ...

        def triggered(self, dt: float) -> None: ...

    class QLogicAspect(Qt3DCore.QAbstractAspect):

        def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None: ...
